	SUBROUTINE DIEOFFS(TOFDAY,DAYOFY,DELT,T90)
	
C	Calculates faecal coliform dieoff T90 based on solar radiation during
C	the time interval DELT(sec). 
C	Input Time of day (hrs) TOFDAY, Day of year (1-366) DAYOFY.
C	Output T90 (hrs)

	REAL TOFDAY,DAYOFY,LAT,LONG,ELEVAT,DELT,DELTH,STANM
	REAL TSOLHR,T90

	COMMON/INPUTS/LAT,LONG,ELEVAT,STANM
	COMMON/MET/WETBLB,ATMPR,DRYBLB,CLOUD,DAT

	LAT=-33.8
	LONG=151.3
	ELEVAT=0.0     ! Elevation (m)
	DELTH=DELT/3600.
	STANM=150.0    ! Longitude corresponding to standard time 
	WETBLB=20.0    ! Dry bulb temp
	DRYBLB=17.5    ! Wet bulb temp (depends on humidity)
	CLOUD=0.0       ! Cloud cover (0-1)
	ATMPR=1015.    ! Atm pressure
	DAT=0.07       ! Dust attenuation

C	Dieoff-Solar Radiation Parameters
C	Ref. Caldwell-Connell Engineers (1980) Fig. 7.6
	A=3.3
	B=-0.7
	
	CALL HEATEX(TOFDAY,DAYOFY,DELT,TSOLHR)

C	Convert radiation in DELT to hourly solar radiation in MJ/m2 
	TSOLHR=TSOLHR/1000./DELTH
C	PRINT*,TSOLHR
C	Calculate the T90
	IF (TSOLHR.LT.0.08) THEN
	  T90=20.
	ELSE
	  T90=A*(TSOLHR**(B))
	ENDIF

	RETURN
	END
